##  Organization
  * Identify organizational units represented in the diagram (e.g., as dotted squares or specific shapes). Note their relationships to applications and other elements.
  * Extract organizational structures showing reporting lines, departments, and their relationships to business capabilities or applications.
